summaryrefslogtreecommitdiffstats
path: root/klipper/configdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'klipper/configdialog.h')
-rw-r--r--klipper/configdialog.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/klipper/configdialog.h b/klipper/configdialog.h
index b7aa26659..9012719d0 100644
--- a/klipper/configdialog.h
+++ b/klipper/configdialog.h
@@ -237,11 +237,11 @@ public:
ListView( ConfigDialog* configWidget, TQWidget *parent, const char *name )
: KListView( parent, name ), _configWidget( configWidget ),
_regExpEditor(0L) {}
- // TQListView has a weird idea of a sizeHint...
- virtual TQSize sizeHint () const {
- int w = minimumSizeHint().width();
+ // TQListView has a weird idea of a tqsizeHint...
+ virtual TQSize tqsizeHint () const {
+ int w = tqminimumSizeHint().width();
int h = header()->height();
- h += viewport()->sizeHint().height();
+ h += viewport()->tqsizeHint().height();
h += horizontalScrollBar()->height();
TQListViewItem *item = firstChild();